# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from uuid import UUID
from authentik_client.models.policy_engine_mode import PolicyEngineMode
from authentik_client.models.themed_urls import ThemedUrls
from authentik_client.models.user_matching_mode_enum import UserMatchingModeEnum
from typing import Optional, Set
from typing_extensions import Self

class Source(BaseModel):
    """
    Source Serializer
    """ # noqa: E501
    pk: UUID
    name: StrictStr = Field(description="Source's display Name.")
    slug: Annotated[str, Field(strict=True)] = Field(description="Internal source name, used in URLs.")
    enabled: Optional[StrictBool] = None
    promoted: Optional[StrictBool] = Field(default=None, description="When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.")
    authentication_flow: Optional[UUID] = Field(default=None, description="Flow to use when authenticating existing users.")
    enrollment_flow: Optional[UUID] = Field(default=None, description="Flow to use when enrolling new users.")
    user_property_mappings: Optional[List[UUID]] = None
    group_property_mappings: Optional[List[UUID]] = None
    component: StrictStr = Field(description="Get object component so that we know how to edit the object")
    verbose_name: StrictStr = Field(description="Return object's verbose_name")
    verbose_name_plural: StrictStr = Field(description="Return object's plural verbose_name")
    meta_model_name: StrictStr = Field(description="Return internal model name")
    policy_engine_mode: Optional[PolicyEngineMode] = None
    user_matching_mode: Optional[UserMatchingModeEnum] = Field(default=None, description="How the source determines if an existing user should be authenticated or a new user enrolled.")
    managed: Optional[StrictStr] = Field(description="Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.")
    user_path_template: Optional[StrictStr] = None
    icon: Optional[StrictStr] = None
    icon_url: Optional[StrictStr] = Field(description="Get the URL to the source icon")
    icon_themed_urls: Optional[ThemedUrls]
    __properties: ClassVar[List[str]] = ["pk", "name", "slug", "enabled", "promoted", "authentication_flow", "enrollment_flow", "user_property_mappings", "group_property_mappings", "component", "verbose_name", "verbose_name_plural", "meta_model_name", "policy_engine_mode", "user_matching_mode", "managed", "user_path_template", "icon", "icon_url", "icon_themed_urls"]

    @field_validator('slug')
    def slug_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[-a-zA-Z0-9_]+$", value):
            raise ValueError(r"must validate the regular expression /^[-a-zA-Z0-9_]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Source from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pk",
            "component",
            "verbose_name",
            "verbose_name_plural",
            "meta_model_name",
            "managed",
            "icon_url",
            "icon_themed_urls",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of icon_themed_urls
        if self.icon_themed_urls:
            _dict['icon_themed_urls'] = self.icon_themed_urls.to_dict()
        # set to None if authentication_flow (nullable) is None
        # and model_fields_set contains the field
        if self.authentication_flow is None and "authentication_flow" in self.model_fields_set:
            _dict['authentication_flow'] = None

        # set to None if enrollment_flow (nullable) is None
        # and model_fields_set contains the field
        if self.enrollment_flow is None and "enrollment_flow" in self.model_fields_set:
            _dict['enrollment_flow'] = None

        # set to None if managed (nullable) is None
        # and model_fields_set contains the field
        if self.managed is None and "managed" in self.model_fields_set:
            _dict['managed'] = None

        # set to None if icon_url (nullable) is None
        # and model_fields_set contains the field
        if self.icon_url is None and "icon_url" in self.model_fields_set:
            _dict['icon_url'] = None

        # set to None if icon_themed_urls (nullable) is None
        # and model_fields_set contains the field
        if self.icon_themed_urls is None and "icon_themed_urls" in self.model_fields_set:
            _dict['icon_themed_urls'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Source from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pk": obj.get("pk"),
            "name": obj.get("name"),
            "slug": obj.get("slug"),
            "enabled": obj.get("enabled"),
            "promoted": obj.get("promoted"),
            "authentication_flow": obj.get("authentication_flow"),
            "enrollment_flow": obj.get("enrollment_flow"),
            "user_property_mappings": obj.get("user_property_mappings"),
            "group_property_mappings": obj.get("group_property_mappings"),
            "component": obj.get("component"),
            "verbose_name": obj.get("verbose_name"),
            "verbose_name_plural": obj.get("verbose_name_plural"),
            "meta_model_name": obj.get("meta_model_name"),
            "policy_engine_mode": obj.get("policy_engine_mode"),
            "user_matching_mode": obj.get("user_matching_mode"),
            "managed": obj.get("managed"),
            "user_path_template": obj.get("user_path_template"),
            "icon": obj.get("icon"),
            "icon_url": obj.get("icon_url"),
            "icon_themed_urls": ThemedUrls.from_dict(obj["icon_themed_urls"]) if obj.get("icon_themed_urls") is not None else None
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.open_id_connect_configuration import OpenIDConnectConfiguration

class TestOpenIDConnectConfiguration(unittest.TestCase):
    """OpenIDConnectConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OpenIDConnectConfiguration:
        """Test OpenIDConnectConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OpenIDConnectConfiguration`
        """
        model = OpenIDConnectConfiguration()
        if include_optional:
            return OpenIDConnectConfiguration(
                issuer = '',
                authorization_endpoint = '',
                token_endpoint = '',
                userinfo_endpoint = '',
                end_session_endpoint = '',
                introspection_endpoint = '',
                jwks_uri = '',
                response_types_supported = [
                    ''
                    ],
                id_token_signing_alg_values_supported = [
                    ''
                    ],
                subject_types_supported = [
                    ''
                    ],
                token_endpoint_auth_methods_supported = [
                    ''
                    ]
            )
        else:
            return OpenIDConnectConfiguration(
                issuer = '',
                authorization_endpoint = '',
                token_endpoint = '',
                userinfo_endpoint = '',
                end_session_endpoint = '',
                introspection_endpoint = '',
                jwks_uri = '',
                response_types_supported = [
                    ''
                    ],
                id_token_signing_alg_values_supported = [
                    ''
                    ],
                subject_types_supported = [
                    ''
                    ],
                token_endpoint_auth_methods_supported = [
                    ''
                    ],
        )
        """

    def testOpenIDConnectConfiguration(self):
        """Test OpenIDConnectConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List
from uuid import UUID
from authentik_client.models.content_type import ContentType
from authentik_client.models.partial_user import PartialUser
from typing import Optional, Set
from typing_extensions import Self

class DataExport(BaseModel):
    """
    Mixin to validate that a valid enterprise license exists before allowing to save the object
    """ # noqa: E501
    id: UUID
    requested_by: PartialUser
    requested_on: datetime
    content_type: ContentType
    var_query_params: Dict[str, Any] = Field(alias="query_params")
    file_url: StrictStr
    completed: StrictBool
    __properties: ClassVar[List[str]] = ["id", "requested_by", "requested_on", "content_type", "query_params", "file_url", "completed"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DataExport from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "requested_by",
            "requested_on",
            "content_type",
            "file_url",
            "completed",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of requested_by
        if self.requested_by:
            _dict['requested_by'] = self.requested_by.to_dict()
        # override the default output from pydantic by calling `to_dict()` of content_type
        if self.content_type:
            _dict['content_type'] = self.content_type.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DataExport from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "requested_by": PartialUser.from_dict(obj["requested_by"]) if obj.get("requested_by") is not None else None,
            "requested_on": obj.get("requested_on"),
            "content_type": ContentType.from_dict(obj["content_type"]) if obj.get("content_type") is not None else None,
            "query_params": obj.get("query_params"),
            "file_url": obj.get("file_url"),
            "completed": obj.get("completed")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from authentik_client.models.device_group_request import DeviceGroupRequest
from authentik_client.models.device_user_request import DeviceUserRequest
from authentik_client.models.disk_request import DiskRequest
from authentik_client.models.hardware_request import HardwareRequest
from authentik_client.models.network_request import NetworkRequest
from authentik_client.models.operating_system_request import OperatingSystemRequest
from authentik_client.models.process_request import ProcessRequest
from authentik_client.models.software_request import SoftwareRequest
from typing import Optional, Set
from typing_extensions import Self

class DeviceFactsRequest(BaseModel):
    """
    DeviceFactsRequest
    """ # noqa: E501
    os: Optional[OperatingSystemRequest] = None
    disks: Optional[List[DiskRequest]] = None
    network: Optional[NetworkRequest] = None
    hardware: Optional[HardwareRequest] = None
    software: Optional[List[SoftwareRequest]] = None
    processes: Optional[List[ProcessRequest]] = None
    users: Optional[List[DeviceUserRequest]] = None
    groups: Optional[List[DeviceGroupRequest]] = None
    vendor: Optional[Dict[str, Any]] = None
    __properties: ClassVar[List[str]] = ["os", "disks", "network", "hardware", "software", "processes", "users", "groups", "vendor"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DeviceFactsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of os
        if self.os:
            _dict['os'] = self.os.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in disks (list)
        _items = []
        if self.disks:
            for _item_disks in self.disks:
                if _item_disks:
                    _items.append(_item_disks.to_dict())
            _dict['disks'] = _items
        # override the default output from pydantic by calling `to_dict()` of network
        if self.network:
            _dict['network'] = self.network.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hardware
        if self.hardware:
            _dict['hardware'] = self.hardware.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in software (list)
        _items = []
        if self.software:
            for _item_software in self.software:
                if _item_software:
                    _items.append(_item_software.to_dict())
            _dict['software'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in processes (list)
        _items = []
        if self.processes:
            for _item_processes in self.processes:
                if _item_processes:
                    _items.append(_item_processes.to_dict())
            _dict['processes'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in users (list)
        _items = []
        if self.users:
            for _item_users in self.users:
                if _item_users:
                    _items.append(_item_users.to_dict())
            _dict['users'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in groups (list)
        _items = []
        if self.groups:
            for _item_groups in self.groups:
                if _item_groups:
                    _items.append(_item_groups.to_dict())
            _dict['groups'] = _items
        # set to None if os (nullable) is None
        # and model_fields_set contains the field
        if self.os is None and "os" in self.model_fields_set:
            _dict['os'] = None

        # set to None if disks (nullable) is None
        # and model_fields_set contains the field
        if self.disks is None and "disks" in self.model_fields_set:
            _dict['disks'] = None

        # set to None if network (nullable) is None
        # and model_fields_set contains the field
        if self.network is None and "network" in self.model_fields_set:
            _dict['network'] = None

        # set to None if hardware (nullable) is None
        # and model_fields_set contains the field
        if self.hardware is None and "hardware" in self.model_fields_set:
            _dict['hardware'] = None

        # set to None if software (nullable) is None
        # and model_fields_set contains the field
        if self.software is None and "software" in self.model_fields_set:
            _dict['software'] = None

        # set to None if processes (nullable) is None
        # and model_fields_set contains the field
        if self.processes is None and "processes" in self.model_fields_set:
            _dict['processes'] = None

        # set to None if users (nullable) is None
        # and model_fields_set contains the field
        if self.users is None and "users" in self.model_fields_set:
            _dict['users'] = None

        # set to None if groups (nullable) is None
        # and model_fields_set contains the field
        if self.groups is None and "groups" in self.model_fields_set:
            _dict['groups'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DeviceFactsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "os": OperatingSystemRequest.from_dict(obj["os"]) if obj.get("os") is not None else None,
            "disks": [DiskRequest.from_dict(_item) for _item in obj["disks"]] if obj.get("disks") is not None else None,
            "network": NetworkRequest.from_dict(obj["network"]) if obj.get("network") is not None else None,
            "hardware": HardwareRequest.from_dict(obj["hardware"]) if obj.get("hardware") is not None else None,
            "software": [SoftwareRequest.from_dict(_item) for _item in obj["software"]] if obj.get("software") is not None else None,
            "processes": [ProcessRequest.from_dict(_item) for _item in obj["processes"]] if obj.get("processes") is not None else None,
            "users": [DeviceUserRequest.from_dict(_item) for _item in obj["users"]] if obj.get("users") is not None else None,
            "groups": [DeviceGroupRequest.from_dict(_item) for _item in obj["groups"]] if obj.get("groups") is not None else None,
            "vendor": obj.get("vendor")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.device_facts_request import DeviceFactsRequest

class TestDeviceFactsRequest(unittest.TestCase):
    """DeviceFactsRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DeviceFactsRequest:
        """Test DeviceFactsRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DeviceFactsRequest`
        """
        model = DeviceFactsRequest()
        if include_optional:
            return DeviceFactsRequest(
                os = authentik_client.models.operating_system_request.OperatingSystemRequest(
                    family = 'linux', 
                    name = '0', 
                    version = '0', 
                    arch = '0', ),
                disks = [
                    authentik_client.models.disk_request.DiskRequest(
                        name = '0', 
                        mountpoint = '0', 
                        label = '', 
                        capacity_total_bytes = 56, 
                        capacity_used_bytes = 56, 
                        encryption_enabled = True, )
                    ],
                network = authentik_client.models.network_request.NetworkRequest(
                    hostname = '0', 
                    firewall_enabled = True, 
                    interfaces = [
                        authentik_client.models.network_interface_request.NetworkInterfaceRequest(
                            name = '0', 
                            hardware_address = '0', 
                            ip_addresses = [
                                '0'
                                ], 
                            dns_servers = [
                                '0'
                                ], )
                        ], 
                    gateway = '0', ),
                hardware = authentik_client.models.hardware_request.HardwareRequest(
                    model = '0', 
                    manufacturer = '0', 
                    serial = '0', 
                    cpu_name = '0', 
                    cpu_count = 56, 
                    memory_bytes = 56, ),
                software = [
                    authentik_client.models.software_request.SoftwareRequest(
                        name = '0', 
                        version = '', 
                        source = '0', 
                        path = '0', )
                    ],
                processes = [
                    authentik_client.models.process_request.ProcessRequest(
                        id = 56, 
                        name = '0', 
                        user = '0', )
                    ],
                users = [
                    authentik_client.models.device_user_request.DeviceUserRequest(
                        id = '0', 
                        username = '0', 
                        name = '0', 
                        home = '0', )
                    ],
                groups = [
                    authentik_client.models.device_group_request.DeviceGroupRequest(
                        id = '0', 
                        name = '0', )
                    ],
                vendor = {
                    'key' : null
                    }
            )
        else:
            return DeviceFactsRequest(
        )
        """

    def testDeviceFactsRequest(self):
        """Test DeviceFactsRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from authentik_client.models.connector import Connector
from authentik_client.models.device_fact_snapshot import DeviceFactSnapshot
from typing import Optional, Set
from typing_extensions import Self

class DeviceConnection(BaseModel):
    """
    DeviceConnection
    """ # noqa: E501
    device: UUID
    connector: UUID
    connector_obj: Connector
    latest_snapshot: Optional[DeviceFactSnapshot]
    __properties: ClassVar[List[str]] = ["device", "connector", "connector_obj", "latest_snapshot"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DeviceConnection from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "connector_obj",
            "latest_snapshot",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of connector_obj
        if self.connector_obj:
            _dict['connector_obj'] = self.connector_obj.to_dict()
        # override the default output from pydantic by calling `to_dict()` of latest_snapshot
        if self.latest_snapshot:
            _dict['latest_snapshot'] = self.latest_snapshot.to_dict()
        # set to None if latest_snapshot (nullable) is None
        # and model_fields_set contains the field
        if self.latest_snapshot is None and "latest_snapshot" in self.model_fields_set:
            _dict['latest_snapshot'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DeviceConnection from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "device": obj.get("device"),
            "connector": obj.get("connector"),
            "connector_obj": Connector.from_dict(obj["connector_obj"]) if obj.get("connector_obj") is not None else None,
            "latest_snapshot": DeviceFactSnapshot.from_dict(obj["latest_snapshot"]) if obj.get("latest_snapshot") is not None else None
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.patched_ssf_provider_request import PatchedSSFProviderRequest

class TestPatchedSSFProviderRequest(unittest.TestCase):
    """PatchedSSFProviderRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedSSFProviderRequest:
        """Test PatchedSSFProviderRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedSSFProviderRequest`
        """
        model = PatchedSSFProviderRequest()
        if include_optional:
            return PatchedSSFProviderRequest(
                name = '0',
                signing_key = '',
                oidc_auth_providers = [
                    56
                    ],
                event_retention = '0'
            )
        else:
            return PatchedSSFProviderRequest(
        )
        """

    def testPatchedSSFProviderRequest(self):
        """Test PatchedSSFProviderRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.lifecycle_api import LifecycleApi


class TestLifecycleApi(unittest.TestCase):
    """LifecycleApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LifecycleApi()

    def tearDown(self) -> None:
        pass

    def test_lifecycle_iterations_create(self) -> None:
        """Test case for lifecycle_iterations_create

        """
        pass

    def test_lifecycle_iterations_latest_retrieve(self) -> None:
        """Test case for lifecycle_iterations_latest_retrieve

        """
        pass

    def test_lifecycle_iterations_list_open(self) -> None:
        """Test case for lifecycle_iterations_list_open

        """
        pass

    def test_lifecycle_reviews_create(self) -> None:
        """Test case for lifecycle_reviews_create

        """
        pass

    def test_lifecycle_rules_create(self) -> None:
        """Test case for lifecycle_rules_create

        """
        pass

    def test_lifecycle_rules_destroy(self) -> None:
        """Test case for lifecycle_rules_destroy

        """
        pass

    def test_lifecycle_rules_list(self) -> None:
        """Test case for lifecycle_rules_list

        """
        pass

    def test_lifecycle_rules_partial_update(self) -> None:
        """Test case for lifecycle_rules_partial_update

        """
        pass

    def test_lifecycle_rules_retrieve(self) -> None:
        """Test case for lifecycle_rules_retrieve

        """
        pass

    def test_lifecycle_rules_update(self) -> None:
        """Test case for lifecycle_rules_update

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Device(BaseModel):
    """
    Serializer for authenticator devices
    """ # noqa: E501
    verbose_name: StrictStr = Field(description="Return object's verbose_name")
    verbose_name_plural: StrictStr = Field(description="Return object's plural verbose_name")
    meta_model_name: StrictStr = Field(description="Return internal model name")
    pk: StrictStr
    name: StrictStr
    type: StrictStr = Field(description="Get type of device")
    confirmed: StrictBool
    created: datetime
    last_updated: datetime
    last_used: Optional[datetime]
    extra_description: Optional[StrictStr] = Field(description="Get extra description")
    external_id: Optional[StrictStr] = Field(description="Get external Device ID")
    __properties: ClassVar[List[str]] = ["verbose_name", "verbose_name_plural", "meta_model_name", "pk", "name", "type", "confirmed", "created", "last_updated", "last_used", "extra_description", "external_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Device from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "verbose_name",
            "verbose_name_plural",
            "meta_model_name",
            "type",
            "created",
            "last_updated",
            "last_used",
            "extra_description",
            "external_id",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if last_used (nullable) is None
        # and model_fields_set contains the field
        if self.last_used is None and "last_used" in self.model_fields_set:
            _dict['last_used'] = None

        # set to None if extra_description (nullable) is None
        # and model_fields_set contains the field
        if self.extra_description is None and "extra_description" in self.model_fields_set:
            _dict['extra_description'] = None

        # set to None if external_id (nullable) is None
        # and model_fields_set contains the field
        if self.external_id is None and "external_id" in self.model_fields_set:
            _dict['external_id'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Device from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "verbose_name": obj.get("verbose_name"),
            "verbose_name_plural": obj.get("verbose_name_plural"),
            "meta_model_name": obj.get("meta_model_name"),
            "pk": obj.get("pk"),
            "name": obj.get("name"),
            "type": obj.get("type"),
            "confirmed": obj.get("confirmed"),
            "created": obj.get("created"),
            "last_updated": obj.get("last_updated"),
            "last_used": obj.get("last_used"),
            "extra_description": obj.get("extra_description"),
            "external_id": obj.get("external_id")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.email_stage_request import EmailStageRequest

class TestEmailStageRequest(unittest.TestCase):
    """EmailStageRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EmailStageRequest:
        """Test EmailStageRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EmailStageRequest`
        """
        model = EmailStageRequest()
        if include_optional:
            return EmailStageRequest(
                name = '0',
                use_global_settings = True,
                host = '0',
                port = -2147483648,
                username = '',
                password = '',
                use_tls = True,
                use_ssl = True,
                timeout = -2147483648,
                from_address = '0',
                token_expiry = '0',
                subject = '0',
                template = '0',
                activate_user_on_success = True,
                recovery_max_attempts = 0,
                recovery_cache_timeout = '0'
            )
        else:
            return EmailStageRequest(
                name = '0',
        )
        """

    def testEmailStageRequest(self):
        """Test EmailStageRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.5.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.lifecycle_iteration import LifecycleIteration

class TestLifecycleIteration(unittest.TestCase):
    """LifecycleIteration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LifecycleIteration:
        """Test LifecycleIteration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LifecycleIteration`
        """
        model = LifecycleIteration()
        if include_optional:
            return LifecycleIteration(
                id = '',
                content_type = 'authentik_core.application',
                object_id = '',
                object_verbose = '',
                object_admin_url = '',
                state = 'REVIEWED',
                opened_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                grace_period_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                next_review_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                reviews = [
                    authentik_client.models.review.Review(
                        id = '', 
                        iteration = '', 
                        reviewer = null, 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        note = '', )
                    ],
                user_can_review = True,
                reviewer_groups = [
                    authentik_client.models.reviewer_group.ReviewerGroup(
                        pk = '', 
                        name = '', )
                    ],
                min_reviewers = 56,
                reviewers = [
                    authentik_client.models.reviewer_user.ReviewerUser(
                        pk = 56, 
                        uuid = '', 
                        username = 'A', 
                        name = '', )
                    ]
            )
        else:
            return LifecycleIteration(
                id = '',
                content_type = 'authentik_core.application',
                object_id = '',
                object_verbose = '',
                object_admin_url = '',
                state = 'REVIEWED',
                opened_on = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                grace_period_end = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                next_review_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                reviews = [
                    authentik_client.models.review.Review(
                        id = '', 
                        iteration = '', 
                        reviewer = null, 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        note = '', )
                    ],
                user_can_review = True,
                reviewer_groups = [
                    authentik_client.models.reviewer_group.ReviewerGroup(
                        pk = '', 
                        name = '', )
                    ],
                min_reviewers = 56,
                reviewers = [
                    authentik_client.models.reviewer_user.ReviewerUser(
                        pk = 56, 
                        uuid = '', 
                        username = 'A', 
                        name = '', )
                    ],
        )
        """

    def testLifecycleIteration(self):
        """Test LifecycleIteration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
